diff --git a/Simulation/FastSimulation/FastChainPileup/test/test_g4ms_validation.sh b/Simulation/FastSimulation/FastChainPileup/test/test_g4ms_validation.sh
index b0daa560e85fe5302956b801d0e6cf4d0fe84de2..4c1f8434b5f21f6446640f1c5c16f3f69d9f2071 100755
--- a/Simulation/FastSimulation/FastChainPileup/test/test_g4ms_validation.sh
+++ b/Simulation/FastSimulation/FastChainPileup/test/test_g4ms_validation.sh
@@ -3,8 +3,10 @@
 # art-description: test
 #
 # art-type: grid
-# art-include: master/Athena
+# art-input: mc16_13TeV.410470.PhPy8EG_A14_ttbar_hdamp258p75_nonallhad.merge.EVNT.e6337_e5984
+# art-input-nfiles: 1
 # art-cores: 10
+# art-include: master/Athena
 # art-output: *.root
 # art-output: art_core*
 # art-output: dcube-*
@@ -34,27 +36,32 @@ case $ArtProcess in
 
         dcubeXmlNTUP="/cvmfs/atlas-nightlies.cern.ch/repo/data/data-art/FastChainPileup/DCube-configs/${AtlasBuildBranch}/physval-validation.xml"
         dcubeRefNTUP="/cvmfs/atlas-nightlies.cern.ch/repo/data/data-art/FastChainPileup/DCube-refs/${AtlasBuildBranch}/test_g4ms_validation/${merge_ntup_file}"
-        dcubeRefAF2NTUP="/cvmfs/atlas-nightlies.cern.ch/repo/data/data-art/FastChainPileup/DCube-refs/${AtlasBuildBranch}/test_af2_validation/physval_af2_validation_all.root"
+        dcubeRefAF2NTUP="/cvmfs/atlas-nightlies.cern.ch/repo/data/data-art/FastChainPileup/DCube-refs/${AtlasBuildBranch}/test_af2_validation/physval_af2_validation_merge.root"
 
         # Histogram comparison of G4MS with AF2 DCube
-        $ATLAS_LOCAL_ROOT/dcube/current/DCubeClient/python/dcube.py \
-        -p -x dcube-physval \
-        -c ${dcubeXmlNTUP} -r ${dcubeRefNTUP} ./${merge_ntup_file}
-        echo  "art-result: $? dcube-physval"
+         $ATLAS_LOCAL_ROOT/dcube/current/DCubeClient/python/dcube.py \
+         -p -x dcube-physval \
+         -c ${dcubeXmlNTUP} -r ${dcubeRefNTUP} ./${merge_ntup_file}
+         echo  "art-result: $? dcube-physval"
 
-        # Histogram comparison of G4MS with AF2 DCube
-        $ATLAS_LOCAL_ROOT/dcube/current/DCubeClient/python/dcube.py \
-        -p -x dcube-g4msVsaf2 \
-        -c ${dcubeXmlNTUP} -r ${dcubeRefAF2NTUP} ./${merge_ntup_file}
-        echo  "art-result: $? dcube-g4msVsaf2"
+         # Histogram comparison of G4MS with AF2 DCube
+         $ATLAS_LOCAL_ROOT/dcube/current/DCubeClient/python/dcube.py \
+         -p -x dcube-g4msVsaf2 \
+         -c ${dcubeXmlNTUP} -r ${dcubeRefAF2NTUP} ./${merge_ntup_file}
+         echo  "art-result: $? dcube-g4msVsaf2"
 
 	;;
 
     *)
 	echo "Test $ArtProcess"
-	
+
 	mkdir "art_core_${ArtProcess}"
 	cd "art_core_${ArtProcess}"
+
+        IFS=',' read -r -a file <<< "${ArtInFile}"
+        file=${file[0]}
+        x="../$file"
+
         
         max_events=1000
         skip_events=$((${max_events}*${ArtProcess}))
@@ -64,7 +71,7 @@ case $ArtProcess in
 	unset  ATHENA_NUM_PROC
 	
         # Output files to be saved
-        hist_file=HITS_${ArtProcess}.pool.root
+        hits_file=HITS_${ArtProcess}.pool.root
         aod_file=AOD_${ArtProcess}.pool.root
         ntup_file=physval_g4ms_${ArtProcess}.root
 
@@ -76,8 +83,8 @@ case $ArtProcess in
                   --preInclude 'EVNTtoHITS:SimulationJobOptions/preInclude.BeamPipeKill.py' \
                   --preExec 'EVNTtoHITS:simFlags.TightMuonStepping=True' \
                   --DataRunNumber '284500' --geometryVersion 'default:ATLAS-R2-2016-01-00-01' \
-                  --inputEVNTFile='/cvmfs/atlas-nightlies.cern.ch/repo/data/data-art/FastChainPileup/mc16_13TeV.410470.PhPy8EG_A14_ttbar_hdamp258p75_nonallhad.merge.EVNT.e6337_e5984_tid12860049_00/EVNT.12860049._002516.pool.root.1' \
-                  --outputHITSFile=${hist_file} \
+                  --inputEVNTFile=${x} \
+                  --outputHITSFile=${hits_file} \
                   --maxEvents ${max_events} --skipEvents ${skip_events} \
                   --randomSeed=1234 --imf False
         rc=$?
@@ -85,7 +92,7 @@ case $ArtProcess in
         if [ $rc -eq 0 ]
         then
             Reco_tf.py --autoConfiguration 'everything' \
-                  --inputHITSFile=${hist_file} --conditionsTag 'default:OFLCOND-MC16-SDR-25' \
+                  --inputHITSFile=${hits_file} --conditionsTag 'default:OFLCOND-MC16-SDR-25' \
                   --geometryVersion 'default:ATLAS-R2-2016-01-00-01' \
                   --postExec "all:CfgMgr.MessageSvc().setError+=['HepMcParticleLink']" \
                   --postInclude "default:PyJobTransforms/UseFrontier.py" \
@@ -98,7 +105,7 @@ case $ArtProcess in
 	    echo  "art-result: $rc2 Reco_${ArtProcess}"
             # if no problem, remove all files except the output files
 	fi
         # for i in `ls | grep -v "${aod_file}\|${hist_file}\|${ntup_file}"` ; do rm -vrf $i; done
         for i in `ls | grep -v "${aod_file}\|${ntup_file}"` ; do rm -vrf $i; done
@@ -98,7 +105,7 @@ case $ArtProcess in
             # if no problem, remove all files except the output files
 	fi
-        # for i in `ls | grep -v "${aod_file}\|${hist_file}\|${ntup_file}"` ; do rm -vrf $i; done
+        # for i in `ls | grep -v "${aod_file}\|${hits_file}\|${ntup_file}"` ; do rm -vrf $i; done
         for i in `ls | grep -v "${aod_file}\|${ntup_file}"` ; do rm -vrf $i; done